
#include "VKSimData.hh"

#include <TSystem.h>
#include <TApplication.h>
#include <TParameter.h>

#include <stdexcept>    // std::invalid_argument

using namespace std;


VKSimData::VKSimData(string filename)
{
    // get tree
    string errMessage = filename + " does not exist.";
    if (gSystem->AccessPathName(filename.c_str())) throw invalid_argument(errMessage);
    fInputFile  = new TFile(filename.c_str(), "READ");
    fInputTree = (TTree*)fInputFile -> Get("Detector"); 
    SetInputBranches(fInputTree);

    // number of events going to output file
    fEntries = fInputTree -> GetEntries();

    // normalization
    fNormalization = 
        ((TParameter<double>*)(fInputTree->GetUserInfo()->FindObject("NORMALIZATION")))->GetVal();

    // area
    fArea =
        ((TParameter<double>*)(fInputTree->GetUserInfo()->FindObject("SOURCE_AREA/cm2")))->GetVal();

    _ESin = 0;
    _EVin = 0;
    _PSin = 0;
    _PVin = 0;        
    _EF2in = 0;
    _ES2in = 0;
    _EV2in = 0;
}


VKSimData::~VKSimData() 
{
    // make sure input ROOT file has been closed
    if (fInputFile != NULL && fInputFile->IsOpen()) fInputFile->Close();

    // delete pointers
    delete fInputFile;
    delete fInputTree;
}


void VKSimData::SetInputBranches(TTree * t) 
{
    if (t->GetBranch("EDepSignal"))
        t->SetBranchAddress("EDepSignal", &_ESin);

    if (t->GetBranch("EDepVeto"))
        t->SetBranchAddress("EDepVeto"  , &_EVin);

    if (t->GetBranch("PhotonsSignal"))
        t->SetBranchAddress("PhotonsSignal", &_PSin);

    if (t->GetBranch("PhotonsSignal"))
        t->SetBranchAddress("PhotonsVeto"  , &_PVin);

    if (t->GetBranch("EDepV2Front"))
        t->SetBranchAddress("EDepV2Front", &_EF2in);

    if (t->GetBranch("EDepV2Signal"))
        t->SetBranchAddress("EDepV2Signal", &_ES2in);

    if (t->GetBranch("EDepV2Veto"))
        t->SetBranchAddress("EDepV2Veto"  , &_EV2in);
}


const VKEvent& VKSimData::GetEvent(size_t id)
{
    fInputTree -> GetEvent(id);
    fEvent.ES = _ESin;
    fEvent.EV = _EVin;
    fEvent.PS = _PSin;
    fEvent.PV = _PVin;
    fEvent.EF2 = _EF2in;
    fEvent.ES2 = _ES2in;
    fEvent.EV2 = _EV2in;
    return fEvent;
}
